grib2io.tables.section4_discipline1 API documentation

# grib2io.tables.section4_discipline1

View Source

     1table_4_2_1_0  = {
     2'0':['Flash Flood Guidance (Encoded as an accumulation over a floating subinterval of time between the reference time and valid time)','kg m-2','FFLDG'],
     3'1':['Flash Flood Runoff (Encoded as an accumulation over a floating subinterval of time)','kg m-2','FFLDRO'],
     4'2':['Remotely Sensed Snow Cover','See Table 4.215','RSSC'],
     5'3':['Elevation of Snow-Covered Terrain','See Table 4.216','ESCT'],
     6'4':['Snow Water Equivalent Percent of Normal','%','SWEPON'],
     7'5':['Baseflow-Groundwater Runoff','kg m-2','BGRUN'],
     8'6':['Storm Surface Runoff','kg m-2','SSRUN'],
     9'7':['Discharge from Rivers or Streams','m3 s-1','DISRS'],
    10'8':['Group Water Upper Storage','kg m-2','GWUPS'],
    11'9':['Group Water Lower Storage','kg m-2','GWLOWS'],
    12'10':['Side Flow into River Channel','m3 s-1 m-1','SFLORC'],
    13'11':['River Storage of Water','m3','RVERSW'],
    14'12':['Flood Plain Storage of Water','m3','FLDPSW'],
    15'13':['Depth of Water on Soil Surface','kg m-2','DEPWSS'],
    16'14':['Upstream Accumulated Precipitation','kg m-2','UPAPCP'],
    17'15':['Upstream Accumulated Snow Melt','kg m-2','UPASM'],
    18'16':['Percolation Rate','kg m-2 s-1','PERRATE'],
    19'17':['River outflow of water','m3 s-1','RVEROW'],
    20'18':['Floodplain outflow of water','m3 s-1','FLDPOW'],
    21'19':['Floodpath outflow of water','m3 s-1','FLDPATHOW'],
    22'20':['Water on surface','kg m-2','WATSURF'],
    23'21':['Water Surface Elevation','m','WSE'],
    24'22':['Groundwater Return Flow Rate','m3 s-1','GRFR'],
    25'23':['River and Floodplain Storage','m3','RVERFLDPS'],
    26'24':['Depth Averaged River Velocity','m s-1','DARVERVEL'],
    27'25-191':['Reserved','unknown','unknown'],
    28'192-254':['Reserved for Local Use','unknown','unknown'],
    29'192':['Baseflow-Groundwater Runoff','kg m-2','BGRUN'],
    30'193':['Storm Surface Runoff','kg m-2','SSRUN'],
    31'194':['Flood Hazard Outlook','unknown','FHO'],
    32'196':['Area Hydrologic Discussion','unknown','AHD'],
    33'255':['Missing','unknown','unknown'],
    34}
    35table_4_2_1_1  = {
    36'0':['Conditional percent precipitation amount fractile for an overall period (encoded as an accumulation)','kg m-2','CPPOP'],
    37'1':['Percent Precipitation in a sub-period of an overall period (encoded as a percent accumulation over the sub-period)','%','PPOSP'],
    38'2':['Probability of 0.01 inch of precipitation (POP)','%','POP'],
    39'3-191':['Reserved','unknown','unknown'],
    40'192-254':['Reserved for Local Use','unknown','unknown'],
    41'192':['Probability of Freezing Precipitation','%','CPOZP'],
    42'193':['Percent of Frozen Precipitation','%','CPOFP'],
    43'194':['Probability of Precipitation Exceeding Flash Flood Guidance Values','%','PPFFG'],
    44'195':['Probability of Wetting Rain, exceeding in 0.10" in a given time period','%','CWR'],
    45'196':['Binary Probability of Precipitation Exceeding Average Recurrence Intervals (ARI)','see Code table 4.222','QPFARI'],
    46'197':['Binary Probability of Precipitation Exceeding Flash Flood Guidance Values','see Code table 4.222','QPFFFG'],
    47'255':['Missing','unknown','unknown'],
    48}
    49table_4_2_1_2  = {
    50'0':['Water Depth','m','WDPTHIL'],
    51'1':['Water Temperature','K','WTMPIL'],
    52'2':['Water Fraction','Proportion','WFRACT'],
    53'3':['Sediment Thickness','m','SEDTK'],
    54'4':['Sediment Temperature','K','SEDTMP'],
    55'5':['Ice Thickness','m','ICTKIL'],
    56'6':['Ice Temperature','K','ICETIL'],
    57'7':['Ice Cover','Proportion','ICECIL'],
    58'8':['Land Cover (0=water, 1=land)','Proportion','LANDIL'],
    59'9':['Shape Factor with Respect to Salinity Profile','unknown','SFSAL'],
    60'10':['Shape Factor with Respect to Temperature Profile in Thermocline','unknown','SFTMP'],
    61'11':['Attenuation Coefficient of Water with Respect to Solar Radiation','m-1','ACWSR'],
    62'12':['Salinity','kg kg-1','SALTIL'],
    63'13':['Cross Sectional Area of Flow in Channel','m2','CSAFC'],
    64'14':['Snow Temperature','K','LNDSNOWT'],
    65'15':['Lake Depth','m','LDEPTH'],
    66'16':['River Depth','m','RDEPTH'],
    67'17':['Floodplain Depth','m','FLDPDEPTH'],
    68'18':['Floodplain Flooded Fraction','Proportion','FLDPFLFR'],
    69'19':['Floodplain Flooded Area','m2','FLDPFLAR'],
    70'20':['River Fraction','Proportion','RVERFR'],
    71'21':['River Area','m2','RVERAR'],
    72'22':['Fraction of river coverage plus river related flooding','Proportion','FRCRF'],
    73'23':['Area of river coverage plus river related flooding','m2','ARCRF'],
    74'24-191':['Reserved','unknown','unknown'],
    75'192-254':['Reserved for Local Use','unknown','unknown'],
    76'255':['Missing','unknown','unknown'],
    77}

table_4_2_1_0 = {'0': ['Flash Flood Guidance (Encoded as an accumulation over a floating subinterval of time between the reference time and valid time)', 'kg m-2', 'FFLDG'], '1': ['Flash Flood Runoff (Encoded as an accumulation over a floating subinterval of time)', 'kg m-2', 'FFLDRO'], '2': ['Remotely Sensed Snow Cover', 'See Table 4.215', 'RSSC'], '3': ['Elevation of Snow-Covered Terrain', 'See Table 4.216', 'ESCT'], '4': ['Snow Water Equivalent Percent of Normal', '%', 'SWEPON'], '5': ['Baseflow-Groundwater Runoff', 'kg m-2', 'BGRUN'], '6': ['Storm Surface Runoff', 'kg m-2', 'SSRUN'], '7': ['Discharge from Rivers or Streams', 'm3 s-1', 'DISRS'], '8': ['Group Water Upper Storage', 'kg m-2', 'GWUPS'], '9': ['Group Water Lower Storage', 'kg m-2', 'GWLOWS'], '10': ['Side Flow into River Channel', 'm3 s-1 m-1', 'SFLORC'], '11': ['River Storage of Water', 'm3', 'RVERSW'], '12': ['Flood Plain Storage of Water', 'm3', 'FLDPSW'], '13': ['Depth of Water on Soil Surface', 'kg m-2', 'DEPWSS'], '14': ['Upstream Accumulated Precipitation', 'kg m-2', 'UPAPCP'], '15': ['Upstream Accumulated Snow Melt', 'kg m-2', 'UPASM'], '16': ['Percolation Rate', 'kg m-2 s-1', 'PERRATE'], '17': ['River outflow of water', 'm3 s-1', 'RVEROW'], '18': ['Floodplain outflow of water', 'm3 s-1', 'FLDPOW'], '19': ['Floodpath outflow of water', 'm3 s-1', 'FLDPATHOW'], '20': ['Water on surface', 'kg m-2', 'WATSURF'], '21': ['Water Surface Elevation', 'm', 'WSE'], '22': ['Groundwater Return Flow Rate', 'm3 s-1', 'GRFR'], '23': ['River and Floodplain Storage', 'm3', 'RVERFLDPS'], '24': ['Depth Averaged River Velocity', 'm s-1', 'DARVERVEL'], '25-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Baseflow-Groundwater Runoff', 'kg m-2', 'BGRUN'], '193': ['Storm Surface Runoff', 'kg m-2', 'SSRUN'], '194': ['Flood Hazard Outlook', 'unknown', 'FHO'], '196': ['Area Hydrologic Discussion', 'unknown', 'AHD'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_1_1 = {'0': ['Conditional percent precipitation amount fractile for an overall period (encoded as an accumulation)', 'kg m-2', 'CPPOP'], '1': ['Percent Precipitation in a sub-period of an overall period (encoded as a percent accumulation over the sub-period)', '%', 'PPOSP'], '2': ['Probability of 0.01 inch of precipitation (POP)', '%', 'POP'], '3-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '192': ['Probability of Freezing Precipitation', '%', 'CPOZP'], '193': ['Percent of Frozen Precipitation', '%', 'CPOFP'], '194': ['Probability of Precipitation Exceeding Flash Flood Guidance Values', '%', 'PPFFG'], '195': ['Probability of Wetting Rain, exceeding in 0.10" in a given time period', '%', 'CWR'], '196': ['Binary Probability of Precipitation Exceeding Average Recurrence Intervals (ARI)', 'see Code table 4.222', 'QPFARI'], '197': ['Binary Probability of Precipitation Exceeding Flash Flood Guidance Values', 'see Code table 4.222', 'QPFFFG'], '255': ['Missing', 'unknown', 'unknown']}
table_4_2_1_2 = {'0': ['Water Depth', 'm', 'WDPTHIL'], '1': ['Water Temperature', 'K', 'WTMPIL'], '2': ['Water Fraction', 'Proportion', 'WFRACT'], '3': ['Sediment Thickness', 'm', 'SEDTK'], '4': ['Sediment Temperature', 'K', 'SEDTMP'], '5': ['Ice Thickness', 'm', 'ICTKIL'], '6': ['Ice Temperature', 'K', 'ICETIL'], '7': ['Ice Cover', 'Proportion', 'ICECIL'], '8': ['Land Cover (0=water, 1=land)', 'Proportion', 'LANDIL'], '9': ['Shape Factor with Respect to Salinity Profile', 'unknown', 'SFSAL'], '10': ['Shape Factor with Respect to Temperature Profile in Thermocline', 'unknown', 'SFTMP'], '11': ['Attenuation Coefficient of Water with Respect to Solar Radiation', 'm-1', 'ACWSR'], '12': ['Salinity', 'kg kg-1', 'SALTIL'], '13': ['Cross Sectional Area of Flow in Channel', 'm2', 'CSAFC'], '14': ['Snow Temperature', 'K', 'LNDSNOWT'], '15': ['Lake Depth', 'm', 'LDEPTH'], '16': ['River Depth', 'm', 'RDEPTH'], '17': ['Floodplain Depth', 'm', 'FLDPDEPTH'], '18': ['Floodplain Flooded Fraction', 'Proportion', 'FLDPFLFR'], '19': ['Floodplain Flooded Area', 'm2', 'FLDPFLAR'], '20': ['River Fraction', 'Proportion', 'RVERFR'], '21': ['River Area', 'm2', 'RVERAR'], '22': ['Fraction of river coverage plus river related flooding', 'Proportion', 'FRCRF'], '23': ['Area of river coverage plus river related flooding', 'm2', 'ARCRF'], '24-191': ['Reserved', 'unknown', 'unknown'], '192-254': ['Reserved for Local Use', 'unknown', 'unknown'], '255': ['Missing', 'unknown', 'unknown']}